|PyCorrFit|
===========

|PyPI Version| |Build Status| |Build Status Win| |Coverage Status| |Docs Status|


Documentation
-------------
The documentation of PyCorrFit is available at https://pycorrfit.readthedocs.org.


Problems
--------
If you find a bug or need help with a specific topic, do not hesitate to ask a question
at the `issues page <https://github.com/FCS-analysis/PyCorrFit/wiki/Creating-a-new-issue>`__.



.. |PyCorrFit| image:: https://raw.github.com/FCS-analysis/PyCorrFit/master/doc/Images/PyCorrFit_logo_dark.png
.. |PyPI Version| image:: https://img.shields.io/pypi/v/PyCorrFit.svg
   :target: https://pypi.python.org/pypi/pycorrfit
.. |Build Status| image:: https://img.shields.io/github/actions/workflow/status/FCS-analysis/PyCorrFit/check.yml
   :target: https://github.com/FCS-analysis/PyCorrFit/actions/workflows/check.yml
.. |Build Status Win| image:: https://img.shields.io/appveyor/ci/paulmueller/PyCorrFit/master.svg?label=build_win
   :target: https://ci.appveyor.com/project/paulmueller/pycorrfit
.. |Coverage Status| image:: https://img.shields.io/codecov/c/github/FCS-analysis/PyCorrFit/master.svg
   :target: https://codecov.io/gh/FCS-analysis/PyCorrFit
.. |Docs Status| image:: https://readthedocs.org/projects/pycorrfit/badge/?version=latest
   :target: https://readthedocs.org/projects/pycorrfit/builds/
